import { requestClient } from '#/api/request';

export namespace DeptApi {
  export interface Dept {
    remark: string;
    createTime: string;
    name: string;
    enabled: string;
    id: string;
    children?: Dept[];
  }

  export interface DeptRecord extends Dept {
    id: string;
  }

  export interface DeptTreeData {
    id: number;
    label: string;
    children?: DeptTreeData[];
  }
}

// 添加区域
export function createDept(data: DeptApi.Dept) {
  return requestClient.post(`/api/rest/dept`, data);
}

// 更新区域信息
export function updateDept(data: DeptApi.DeptRecord) {
  return requestClient.patch(`/api/rest/dept/${data.id}`, data);
}

// 删除区域
export function removeDept(id: string) {
  return requestClient.delete(`/api/rest/dept/${id}`);
}

// 模糊查询获取区域列表
export function queryDeptList(data: DeptApi.DeptRecord) {
  return requestClient.get('/api/rest/dept', { data });
}

// 获取区域列表
export function deptList() {
  return requestClient.get(`/api/rest/dept`);
}

// 启用状态
export function enabledDept(id: string) {
  return requestClient.patch(`/api/rest/dept/toggle/${id}`, id);
}

export function getAllDeptTree(id?: number | string) {
  return requestClient.get('/rest/dept/tree', { params: { id } });
}

// export function getDeptTree(params?: Partial<DeptRecord>) {
//   return axios.get<DeptRecord[]>(`/api/dept/trees`, {
//     params,
//     paramsSerializer: (obj) => {
//       return qs.stringify(obj);
//     },
//   });
// }
// export function listDepts(params?: ListParams<Partial<DeptRecord>>) {
//   return axios.get<DeptRecord[]>(`/api/dept`, {
//     params,
//     paramsSerializer: (obj) => {
//       return qs.stringify(obj);
//     },
//   });
// }
// export function queryDepts(params?: ListParams<Partial<DeptRecord>>) {
//   return queryList(`/api/dept`, params);
// }
